%define anolis_release 1
%define alt_ckbi libnssckbi.so

Name:           p11-kit
Version:	0.25.0
Release: 	%{anolis_release}%{?dist}
Summary:        Library for loading and sharing PKCS#11 modules

License:        BSD
URL:            http://p11-glue.freedesktop.org/%{name}.html
Source0:        https://github.com/p11-glue/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        trust-extract-compat
Source2:        %{name}-client.service

BuildRequires:  gcc meson
BuildRequires:  libtasn1-devel >= 2.3 libffi-devel systemd systemd-devel
BuildRequires:  gettext gtk-doc
BuildRequires:  bash-completion pkgconfig(glib-2.0) gnupg2
BuildRequires:  /usr/bin/xsltproc

%description
p11-kit aims to solve problems with coordinating the use of PKCS #11 by
different components or libraries living in the same process, by providing a
way to load and enumerate PKCS #11 modules, as well as a standard configuration
setup for installing PKCS #11 modules in such a way that they're discoverable.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for developing
applications that use %{name}.

%package trust
Summary:            System trust module from %{name}
Requires:           %{name} = %{version}-%{release}
Requires(post):     %{_sbindir}/update-alternatives
Requires(postun):   %{_sbindir}/update-alternatives
Conflicts:          nss < 3.14.3-9

%description trust
The %{name}-trust package contains a system trust PKCS#11 module which contains
certificate anchors and black lists.

%package server
Summary:        Server and client commands for %{name}
Requires:       %{name} = %{version}-%{release}

%description server
The %{name}-server package contains command line tools that enable to export
PKCS#11 modules through a Unix domain socket.  Note that this feature is still
experimental.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%meson \
  -Dtrust_paths=%{_sysconfdir}/pki/ca-trust/source:%{_datadir}/pki/ca-trust-source \
  -Dgtk_doc=true \
  -Dman=true
%meson_build

%install
%meson_install
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pkcs11/modules
install -p -m 0755 %{SOURCE1} $RPM_BUILD_ROOT%{_libexecdir}/%{name}/
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}
mv $RPM_BUILD_ROOT%{_sysconfdir}/pkcs11/pkcs11.conf.example $RPM_BUILD_ROOT%{_docdir}/%{name}/pkcs11.conf.example
mkdir -p $RPM_BUILD_ROOT%{_userunitdir}
install -p -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{_userunitdir}
%find_lang %{name}

%generate_compatibility_deps

%check
%meson_test

%post trust
%{_sbindir}/update-alternatives --install %{_libdir}/%{alt_ckbi} \
        %{alt_ckbi} %{_libdir}/pkcs11/%{name}-trust.so 30

%postun trust
if [ $1 -eq 0 ] ; then
        %{_sbindir}/update-alternatives --remove %{alt_ckbi} %{_libdir}/pkcs11/%{name}-trust.so
fi


%files -f %{name}.lang
%dir %{abidir}
%license COPYING
%{_docdir}/%{name}/pkcs11.conf.example
%dir %{_sysconfdir}/pkcs11
%dir %{_sysconfdir}/pkcs11/modules
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/modules
%dir %{_libexecdir}/%{name}
%{_bindir}/%{name}
%{_libdir}/lib%{name}.so.*
%{_libdir}/%{name}-proxy.so
%{_libexecdir}/%{name}/%{name}-remote
%{_mandir}/man1/trust.1.zst
%{_mandir}/man8/%{name}.8.zst
%{_mandir}/man5/pkcs11.conf.5.zst
%{_datadir}/bash-completion/completions/%{name}
%{abidir}/%{name}-option.list
%{abidir}/lib%{name}*.dump

%files devel
%{_includedir}/%{name}-1/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}-1.pc
%doc %{_datadir}/gtk-doc/

%files trust
%{_bindir}/trust
%dir %{_libdir}/pkcs11
%ghost %{_libdir}/%{alt_ckbi}
%{_libdir}/pkcs11/%{name}-trust.so
%{_datadir}/%{name}/modules/%{name}-trust.module
%{_libexecdir}/%{name}/trust-extract-compat
%{_datadir}/bash-completion/completions/trust
%{abidir}/trust-option.list
%{abidir}/%{name}-trust*.dump

%files server
%{_libdir}/pkcs11/%{name}-client.so
%{abidir}/%{name}-client*.dump
%{_userunitdir}/%{name}-client.service
%{_libexecdir}/%{name}/%{name}-server
%{_userunitdir}/%{name}-server.service
%{_userunitdir}/%{name}-server.socket

%files doc
%doc AUTHORS NEWS README

%changelog
* Mon Feb 19 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.25.0-1
- update to 0.25.0

* Mon Apr 10 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 0.24.1-4
- Optimize the spec file

* Tue Oct 18 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.24.1-3
- optimise spec file

* Sat Oct 08 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.24.1-2
- add doc package

* Tue Mar 08 2022 liuzhilin <liuzhilin@uniontech.com> - 0.24.1-1
- Init for Anolis OS 23
